"""The `mailgun` package provides a Python SDK for interacting with the Mailgun API.

Packages:
    - examples: basic examples.
    - handlers: predefined handlers.

Modules:
    - client: Defines the main API client.

"""
